ObsError

Enum ObsError 

pub enum ObsError {
Show 33 variants Failure, InvalidDll, MutexFailure, ThreadFailure, ResetVideoFailure(ObsResetVideoStatus), ResetVideoFailureGraphicsModule, ResetVideoFailureOutputActive, NullPointer(Option<String>), OutputAlreadyActive, OutputStartFailure(Option<String>), OutputStopFailure(Option<String>), OutputPauseFailure(Option<String>), OutputNotFound, SourceNotFound, SourceNotAvailable(String), InvalidOperation(String), StringConversionError, DisplayCreationError(String), OutputSaveBufferFailure(String), InvocationError(String), JsonParseError, NoSenderError, NoAvailableEncoders, LockError(String), Unexpected(String), EncoderActive, PlatformInitError(String), IoError(String), SignalDataError(String), EnumConversionError(String), RuntimeChannelError(String), RuntimeOutsideThread, FilterAlreadyApplied,
}
Error type for OBS function calls.

Variants



Failure

The obs_startup function failed on libobs.



InvalidDll

This error is emitted if a dummy DLL was loaded instead of the real libobs DLL. Make sure you bootstrap properly with libobs-bootstrapper



MutexFailure

Failed to lock mutex describing whether there is a thread using libobs or not. Report to crate maintainer.



ThreadFailure

Some or no thread is already using libobs. This is a bug!



ResetVideoFailure(ObsResetVideoStatus)

Unable to reset video.



ResetVideoFailureGraphicsModule

Unable to reset video because the program attempted to change the graphics module. This is a bug!



ResetVideoFailureOutputActive

Unable to reset video because some outputs were still active.



NullPointer(Option<String>)

The function returned a null pointer, often indicating an error with creating the object of the requested pointer.



OutputAlreadyActive



OutputStartFailure(Option<String>)



OutputStopFailure(Option<String>)



OutputPauseFailure(Option<String>)



OutputNotFound



SourceNotFound



SourceNotAvailable(String)



InvalidOperation(String)



StringConversionError

Error converting a string between Rust and OBS



DisplayCreationError(String)

Native error from the Windows API when creating a display



OutputSaveBufferFailure(String)



InvocationError(String)

The obs thread couldn’t be called



JsonParseError



NoSenderError

Couldn’t get the sender of the signal



NoAvailableEncoders



LockError(String)

Error locking a mutex or RwLock. You should probably restart the application to avoid memory leaks.



Unexpected(String)



EncoderActive

Encoder is still active, stop the attached output before proceeding



PlatformInitError(String)

Error during platform-specific initialization



IoError(String)

Error reading/writing to a file



SignalDataError(String)

Failed to get data from signal calldata



EnumConversionError(String)

Failed to convert an enum from a code



RuntimeChannelError(String)

Failed to send/receive on a runtime channel



RuntimeOutsideThread

Attempted to call a OBS runtime function from outside the OBS thread. This error should NEVER occur. If you are not using the runtime manually or have the “enable_runtime” feature enabled then please report this to the crate maintainer as this indicates a bug in the crate.



FilterAlreadyApplied

A filter was already applied to a source